===============================
Yowsup Gateway
===============================

.. image:: https://img.shields.io/pypi/v/yowsup-gateway.svg
        :target: https://pypi.python.org/pypi/yowsup-gateway

.. image:: https://img.shields.io/travis/jlmadurga/yowsup-gateway.svg
        :target: https://travis-ci.org/jlmadurga/yowsup-gateway

.. image:: https://readthedocs.org/projects/yowsup-gateway/badge/?version=latest
        :target: https://readthedocs.org/projects/yowsup-gateway/?badge=latest
        :alt: Documentation Status


Yowsup Gateway pretends to be a link between yowsup library and client applications

* Free software: ISC license
* Documentation: https://yowsup-gateway.readthedocs.org.

Features
--------


* 0.1.0 Send and receive text messages


